@@ -14,17 +14,14 @@ class PROJWBS(Node):
     """
 
     def __init__(self, **data: str) -> None:
-        super().__init__()
-        self.uid: str = data["wbs_id"]
-        """Unique Table ID"""
-        self.code: str = data["wbs_short_name"]
-        """WBS Code"""
+        super().__init__(
+            data["wbs_id"],
+            data["wbs_short_name"],
+            data["wbs_name"],
+            data["parent_wbs_id"],
+        )
         self.is_proj_node: bool = data["proj_node_flag"] == "Y"
         """Project Level Code Flag"""
-        self.name: str = data["wbs_name"]
-        """WBS Name"""
-        self.parent_wbs_id: str = data["parent_wbs_id"]
-        """Parent Unique Table ID"""
         self.proj_id: str = data["proj_id"]
         """Foreign Key for `PROJECT` WBS node belongs to"""
         self.seq_num: int | None = optional_int(data["seq_num"])
@@ -35,21 +32,6 @@ class PROJWBS(Node):
         """Activity Assignment Count"""
         self.user_defined_fields: dict[UDFTYPE, Any] = {}
 
-    def __eq__(self, __o: "PROJWBS") -> bool:
-        return self.full_code == __o.full_code
-
-    def __gt__(self, __o: "PROJWBS") -> bool:
-        return self.full_code > __o.full_code
-
-    def __lt__(self, __o: "PROJWBS") -> bool:
-        return self.full_code < __o.full_code
-
-    def __hash__(self) -> int:
-        return hash(self.full_code)
-
-    def __str__(self) -> str:
-        return f"{self.full_code} - {self.name}"
-
     @property
     def lineage(self) -> list["PROJWBS"]:
         if self.is_proj_node:
@@ -62,4 +44,4 @@ class PROJWBS(Node):
 
     @property
     def full_code(self) -> str:
-        return ".".join(reversed([node.code for node in self.lineage]))
+        return ".".join([node.code for node in self.lineage])
