@@ -3,18 +3,16 @@
 # Functions to validate data during object initialization
 
 from datetime import datetime
-from xerparser.schemas.rsrc import RSRC
 
 date_format = "%Y-%m-%d %H:%M"
 
-
-def datetime_or_none(value: str) -> datetime | None:
+def optional_date(value: str) -> datetime | None:
     if value == "" or value is None:
         return None
     return datetime.strptime(value, date_format)
 
 
-def float_or_none(value: str) -> float | None:
+def optional_float(value: str) -> float | None:
     if value == "" or value is None:
         return None
     return float(value)
@@ -26,19 +24,17 @@ def float_or_zero(value: str) -> float:
     return float(value)
 
 
-def int_or_none(value: str) -> int | None:
+def optional_int(value: str) -> int | None:
     if value == "" or value is None:
         return None
     return int(value)
 
 
-def rsrc_or_none(value: RSRC | None) -> RSRC | None:
-    if value is None:
-        return None
-    if not isinstance(value, RSRC):
-        raise ValueError(f"ValueError: expected <class RSRC>; got {type(value)}")
-    return value
+def int_or_zero(value: str) -> int:
+    if value == "" or value is None:
+        return 0
+    return int(value)
 
 
-def str_or_none(value: str) -> str | None:
+def optional_str(value: str) -> str | None:
     return (value, None)[value == ""]
